@@ -9,7 +9,7 @@ class AcceptanceRateMonitor {
   def nAttempts = _nAttempts
   def rate = _nAcceptances / _nAttempts.toDouble
 
-  def apply[B](x: (B, Boolean)) = {
+  def apply[B](x: (B, Boolean)): B = {
     _nAttempts += 1
     if (x._2) _nAcceptances += 1
     x._1
